@@ -18,7 +18,7 @@ int main(int argc, char **argv)
     QPushButton *b = new QPushButton("Show w3.bmp !", v);
     MyQGL *gl = new MyQGL(v);
 
-    QVBox::connect(b, SIGNAL(clicked()), gl, SLOT(bind()));
+    QVBox::connect(b, TQ_SIGNAL(clicked()), gl, TQ_SLOT(bind()));
 
     v->setStretchFactor(gl, 1);
 
