@@ -22,12 +22,14 @@
 #ifndef KSQUIRREL_LIBS_CLASS_DEFINITION_create_destroy_H
 #define KSQUIRREL_LIBS_CLASS_DEFINITION_create_destroy_H
 
-extern "C" fmt_codec_base* codec_create()
+#include "ksquirrel-libs/ksquirrel_libs_export.h"
+
+extern "C" LIBKSQUIRREL_EXPORT fmt_codec_base* codec_create()
 {
     return (new fmt_codec);
 }
 
-extern "C" void codec_destroy(fmt_codec_base *p)
+extern "C" LIBKSQUIRREL_EXPORT void codec_destroy(fmt_codec_base *p)
 {
     delete p;
 }
